#!/bin/bash

# Navigate to the project root directory
cd "$(dirname "$0")"

# Check if the Secrets Manager option is provided (-s)
use_secrets_manager=false
while getopts ":s:" opt; do
  case $opt in
    s)
      use_secrets_manager=true
      ;;
  esac
done

# If Secrets Manager is used, check for AWS credentials
if [ "$use_secrets_manager" = true ]; then
  if [ -z "$AWS_SECRET_ACCESS_KEY" ] || [ -z "$AWS_ACCESS_KEY_ID" ]; then
    echo "Error: AWS_SECRET_ACCESS_KEY and AWS_ACCESS_KEY_ID must be set when using Secrets Manager." >&2
    exit 1
  fi
fi

# Ensure the project is built
if [ ! -f target/CreateBrowsolateUrl-1.0-SNAPSHOT.jar ]; then
    echo "Build the project first."
    exit 1
fi

# Run the Java program with arguments passed to the script
java -jar target/CreateBrowsolateUrl-1.0-SNAPSHOT.jar "$@"
