/*
 * Copyright 2024 Browsolate Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.browsolate;

import java.util.HashMap;
import java.util.Map;

public class CommandLineArgs {
    public String baseUrl;
    public String navigateUrl;
    public String key="default";
    public String secret;
    public String region;
    public String password;
    public boolean ignore_ssl;
    public boolean api;

    // Parse command-line arguments
    public static CommandLineArgs parse(String[] args) {
        CommandLineArgs options = new CommandLineArgs();
        Map<String, String> argMap = new HashMap<>();

        for (int i = 0; i < args.length; i++) {
            switch (args[i]) {
                case "-b":
                case "--base_url":
                    options.baseUrl = args[++i];
                    break;
                case "-u":
                case "--navigate_url":
                    options.navigateUrl = args[++i];
                    break;
                case "-k":
                case "--key":
                    options.key = args[++i];
                    break;
                case "-s":
                case "--secret":
                    options.secret = args[++i];
                    break;
                case "-r":
                case "--region":
                    options.region = args[++i];
                    break;
                case "-i":
                case "--ignore_ssl":
                    options.ignore_ssl = true;
                    break;
                case "-p":
                case "--password":
                    options.password = args[++i];
                    break;
                case "--api":
                    options.api = true;
                    break;
                default:
                    System.err.println("Unknown argument: " + args[i]);
                    System.exit(1);
            }
        }
        return options;
    }
}
